@@ -4,7 +4,7 @@ package Moose;
 BEGIN {
   $Moose::AUTHORITY = 'cpan:STEVAN';
 }
-$Moose::VERSION = '2.1210';
+$Moose::VERSION = '2.1211';
 use 5.008003;
 
 use Scalar::Util 'blessed';
@@ -301,7 +301,7 @@ Moose - A postmodern object system for Perl 5
 
 =head1 VERSION
 
-version 2.1210
+version 2.1211
 
 =head1 SYNOPSIS
 
@@ -915,11 +915,11 @@ respectively.
 
 Metaclass compatibility is a thorny subject. You should start by
 reading the "About Metaclass compatibility" section in the
-C<Class::MOP> docs.
+L<Class::MOP> docs.
 
 Moose will attempt to resolve a few cases of metaclass incompatibility
 when you set the superclasses for a class, in addition to the cases that
-C<Class::MOP> handles.
+L<Class::MOP> handles.
 
 Moose tries to determine if the metaclasses only "differ by roles". This
 means that the parent and child's metaclass share a common ancestor in
